@@ -9,7 +9,7 @@ int main() {
 
   // Define gridsize
   const int Nx=24;
-  const int Ny=49;
+  const int Ny=65;
   const int Nz=24;
 
   // Define box size
@@ -23,12 +23,12 @@ int main() {
   const Real nu = 1.0/Reynolds;
 
   // Define integration parameters
-  const int n = 50;     // take ten steps between printouts
+  const int n = 1;     // take ten steps between printouts
   const Real dt = 0.02;
   const Real T  = 100.0;
 
   // Define size and smoothness of initial disturbance
-  Real decay = 0.6;   
+  Real decay = 0.3;   
   Real magnitude  = 0.01;   
   int kxmax = 3;
   int kzmax = 3;
@@ -56,12 +56,16 @@ int main() {
   DNSFlags flags; 
   flags.timestepping = SBDF3;
   flags.initstepping = CNRK2;
+  flags.nonlinearity = SkewSymmetric;
   //flags.dealiasing = DealiasXZ;
   flags.constraint  = PressureGradient; // enforce constant pressure gradient
 
   DNS dns(u, U, nu, dt, flags);
   cout << "done" << endl;
 
+  PressureSolver psolve(u, U, nu, flags.nonlinearity);
+  FlowField p = q;
+
   for (Real t=0; t<T; t += n*dt) {
     cout << "===============================================" << endl;
     cout << "         t == " << t << endl;
@@ -69,6 +73,7 @@ int main() {
     cout << " L2Norm(u) == " << L2Norm(u) << endl;
     cout << "divNorm(u) == " << divNorm(u) << endl;
     cout << " bcNorm(u) == " << bcNorm(u) << endl;
+    cout << " L2Dist(q,p) == " << L2Dist(q,p) << endl;
 
     // Save the kx=1,kz=2 Fourier profile and the velocity field
     BasisFunc u12 = u.profile(1,2);
@@ -76,7 +81,7 @@ int main() {
 
     // Take n steps of length dt
     dns.advance(u, q, n);
-    cfpause();
+
   }
   u.binarySave("u"+i2s(int(T)));
   q.binarySave("q"+i2s(int(T)));
