@@ -53,7 +53,7 @@ int main() {
 
   DNSFlags flags;
   flags.nonlinearity = Linearized;
-  flags.timestepping = SMRK2;
+  flags.timestepping = SBDF3;
   Real scale =  0.01;
   const char s = ' ';
   
