@@ -1,5 +1,13 @@
-function yzframe(u_yz, v_yz, w_yz, umag, y,z)
+function yzframe(u_yz, v_yz, w_yz, umag, y,z, ystride, zstride)
+% 
 
+  if (nargin < 7)
+    ystride = 2;
+  end
+  if (nargin < 8)
+    zstride = 2;
+  end
+    
   ulim = [-umag:umag/10:umag];
   [C,h] = contourf(z, y, u_yz, ulim); 
   set(h, 'LineStyle', 'none');
@@ -10,8 +18,8 @@ function yzframe(u_yz, v_yz, w_yz, umag, y,z)
   caxis([-umag umag]);
   axis([min(z) max(z) min(y) max(y)]);
 
-  ny2 = 1:2:length(y);
-  nz2 = 1:2:length(z);
+  ny2 = 1:ystride:length(y);
+  nz2 = 1:zstride:length(z);
   y2=y(ny2);
   z2=z(nz2);
   
@@ -26,5 +34,7 @@ function yzframe(u_yz, v_yz, w_yz, umag, y,z)
   
   xlabel('z');
   ylabel('y');
-  set(gca, 'XTick', [minz maxz]);
-  set(gca, 'YTick', [miny maxy]);
+  %set(gca, 'XTick', [minz maxz]);
+  %set(gca, 'YTick', [miny maxy]);
+  set(gca, 'XTick', []);
+  set(gca, 'YTick', []);
