@@ -30,9 +30,10 @@
 #include <fstream>
 #include <iomanip>
 #include "cfvector.h"
+#include <fftw3.h>
 
 Vector::Vector(int N) :
-  data_(new Real[N]),
+  data_((Real*) fftw_malloc(N*sizeof(Real))),
   N_(N)
 {
   //cerr << "Vector ctor " << long(data_) << endl;
@@ -43,7 +44,7 @@ Vector::Vector(int N) :
 }
 
 Vector::Vector(const Vector& a) :
-  data_(new Real[a.N_]),
+  data_((Real*) fftw_malloc(a.N_*sizeof(Real))),
   N_(a.N_)
 {
   //cerr << "Vector ctor " << long(data_) << endl;
@@ -82,7 +83,7 @@ Vector::Vector(const string& filebase) :
   assert(M == 1 || N == 1);
   N_ = (M > N) ? M : N;
 
-  data_ = new Real[N_];
+  data_ = (Real*) fftw_malloc(N_*sizeof(Real));
 
   //char BUFFER[256];
   //is.getline(BUFFER, 256); // Finsh off the first line
@@ -97,7 +98,7 @@ Vector::Vector(const string& filebase) :
 
 void Vector::resize(int newN) {
   if (newN != N_) {
-    Real* newdata = new Real[newN];
+    Real* newdata = (Real*) fftw_malloc(newN*sizeof(Real));
     //cerr << "Vector resize " << long(data_) << " -> " << long(newdata) << endl;
     assert(newdata != 0);
     int shortN = lesser(N_, newN);
@@ -106,7 +107,7 @@ void Vector::resize(int newN) {
       newdata[i] = data_[i];
     for (i=shortN; i<newN; ++i)
       newdata[i] = 0.0;
-    delete[] data_;
+    fftw_free(data_);
     data_ = newdata;
     N_ = newN;
   }
@@ -125,7 +126,7 @@ void Vector::setToZero() {
 
 Vector::~Vector() {
   //cerr << "Vector dtor " << long(data_) << flush; 
-  delete[] data_;
+  fftw_free(data_);
   //cerr << "done" << endl;
   data_=0;
 }
@@ -215,8 +216,8 @@ Vector& Vector::operator=(const Vector& a) {
   if (data_ != a.data_) {
     if (N_ != a.N_) {
       //cout << "delete in operator= on " << long(data_) << endl;
-      delete[] data_;
-      data_ = new Real[a.N_];
+      fftw_free(data_);
+      data_ = (Real*) fftw_malloc(a.N_*sizeof(Real));
       N_ = a.N_;
       assert(data_ != 0);
     }  
