@@ -43,8 +43,8 @@ Vector periodicpoints(int N, Real L); // {0, L/N, ..., (N-1)L/N}
 Real chebyIP(int m, int n); // Integral_(-1)^1 Tm(y) Tn(y) dy
 inline int cheby_c(int n) {return (n>0) ? 1 : ((n==0) ? 2 : 0);}
 
-Real legendre(int n, Real x);    // Value of P_n(x)
-Real chebyshev(int n, Real x);   // Value of T_n(x)
+Real legendre(int n, Real x);    // Value of Legendre polynomial P_n(x)
+Real chebyshev(int n, Real x);   // Value of Chebyshev polynomial T_n(x)
 
 void gaussLegendreQuadrature(int N, Real a, Real b, Vector& x, Vector& w);
 
@@ -116,65 +116,6 @@ private:
   friend class ChebyTransform;
 };
 
-ChebyCoeff operator*(Real c, const ChebyCoeff& g);
-ChebyCoeff operator+(const ChebyCoeff& f, const ChebyCoeff& g);
-ChebyCoeff operator-(const ChebyCoeff& f, const ChebyCoeff& g);
-bool operator==(const ChebyCoeff& f, const ChebyCoeff& g);
-bool operator!=(const ChebyCoeff& f, const ChebyCoeff& g);
-
-void  diff(const ChebyCoeff& f, ChebyCoeff& df);
-void diff2(const ChebyCoeff& f, ChebyCoeff& d2f);
-void diff2(const ChebyCoeff& f, ChebyCoeff& d2f, ChebyCoeff& tmp);
-void  diff(const ChebyCoeff& f, ChebyCoeff& df, int n);
-ChebyCoeff  diff(const ChebyCoeff& f);
-ChebyCoeff diff2(const ChebyCoeff& f);
-ChebyCoeff  diff(const ChebyCoeff& f, int n);
-
-// Integrate sets the arbitrary const of integration so that mean(u)==0.
-void integrate(const ChebyCoeff& df, ChebyCoeff& f);
-ChebyCoeff integrate(const ChebyCoeff& df);
-
-ChebyCoeff legendre(int N, int n, bool normalize=false);
-ChebyCoeff chebyshev(int N, int n, bool normalize=false);
-
-//   normalize  ?   false                  :  true
-// L2Norm2(f)   =      Int_a^b f^2 dy            1/(b-a) Int_a^b f^2 dy    
-// L2Dist2(f,g) =      Int_a^b (f-g)^2 dy        1/(b-a) Int_a^b (f-g)^2 dy 
-// L2Norm(f)    = sqrt(Int_a^b f^2 dy)      sqrt(1/(b-a) Int_a^b f^2 dy)
-// L2Dist(f,g)  = sqrt(Int_a^b (f-g)^2 dy)  sqrt(1/(b-a) Int_a^b (f-g)^2 dy
-// L2IP...(f,g) =      Int_a^b f g dy            1/(b-a) Int_a^b f g dy 
-//                               
-
-Real L2Norm2(const ChebyCoeff& f, bool normalize=true); 
-Real L2Dist2(const ChebyCoeff& f, const ChebyCoeff& g, bool normalize=true); 
-Real L2Norm(const ChebyCoeff& f, bool normalize=true); 
-Real L2Dist(const ChebyCoeff& f, const ChebyCoeff& g, bool normalize=true); 
-Real L2InnerProduct(const ChebyCoeff& f, const ChebyCoeff& g, 
-		    bool normalize=true);
-
-Real chebyNorm2(const ChebyCoeff& f, bool normalize=true); 
-Real chebyDist2(const ChebyCoeff& f, const ChebyCoeff& g, bool normalize=true); 
-Real chebyNorm(const ChebyCoeff& f, bool normalize=true); 
-Real chebyDist(const ChebyCoeff& f, const ChebyCoeff& g, bool normalize=true); 
-Real chebyInnerProduct(const ChebyCoeff& f, const ChebyCoeff& g, 
-		       bool normalize=true);
-
-Real norm2(const ChebyCoeff& f, NormType n, bool normalize=true); 
-Real dist2(const ChebyCoeff& f, NormType n, const ChebyCoeff& g, 
-	   bool normalize=true); 
-Real norm(const ChebyCoeff& f, NormType n, bool normalize=true); 
-Real dist(const ChebyCoeff& f, const ChebyCoeff& g, NormType n, 
-	  bool normalize=true); 
-Real innerProduct(const ChebyCoeff& f, const ChebyCoeff& g, NormType n, 
-		    bool normalize=true);
-
-Real L1Norm(const ChebyCoeff& f, bool normalize=true);
-Real L1Dist(const ChebyCoeff& f, const ChebyCoeff& g, bool normalize=true);
-
-Real LinfNorm(const ChebyCoeff& f); 
-Real LinfDist(const ChebyCoeff& f, const ChebyCoeff& g); 
-
-
 class ComplexChebyCoeff {
 public:
   ComplexChebyCoeff();
@@ -244,6 +185,85 @@ public:
   ChebyCoeff im;
 };
 
+
+class ChebyTransform {
+public:
+  ChebyTransform(int N, int fftw_flags = FFTW_ESTIMATE);
+  ChebyTransform(const ChebyTransform& t);            // unimplemented
+  ChebyTransform& operator=(const ChebyTransform& t); // unimplemented
+  ~ChebyTransform();
+  
+  inline int N() const;
+  inline int length() const;
+
+  friend class ChebyCoeff;
+  friend class ComplexChebyCoeff;
+
+private:
+  int N_; 
+  int flags_;
+  fftw_plan cosfftw_plan_;
+};
+
+ChebyCoeff operator*(Real c, const ChebyCoeff& g);
+ChebyCoeff operator+(const ChebyCoeff& f, const ChebyCoeff& g);
+ChebyCoeff operator-(const ChebyCoeff& f, const ChebyCoeff& g);
+bool operator==(const ChebyCoeff& f, const ChebyCoeff& g);
+bool operator!=(const ChebyCoeff& f, const ChebyCoeff& g);
+
+void  diff(const ChebyCoeff& f, ChebyCoeff& df);
+void diff2(const ChebyCoeff& f, ChebyCoeff& d2f);
+void diff2(const ChebyCoeff& f, ChebyCoeff& d2f, ChebyCoeff& tmp);
+void  diff(const ChebyCoeff& f, ChebyCoeff& df, int n);
+ChebyCoeff  diff(const ChebyCoeff& f);
+ChebyCoeff diff2(const ChebyCoeff& f);
+ChebyCoeff  diff(const ChebyCoeff& f, int n);
+
+// Integrate sets the arbitrary const of integration so that mean(u)==0.
+void integrate(const ChebyCoeff& df, ChebyCoeff& f);
+ChebyCoeff integrate(const ChebyCoeff& df);
+
+ChebyCoeff legendre(int N, int n, bool normalize=false);
+ChebyCoeff chebyshev(int N, int n, bool normalize=false);
+
+//   normalize  ?   false                  :  true
+// L2Norm2(f)   =      Int_a^b f^2 dy            1/(b-a) Int_a^b f^2 dy    
+// L2Dist2(f,g) =      Int_a^b (f-g)^2 dy        1/(b-a) Int_a^b (f-g)^2 dy 
+// L2Norm(f)    = sqrt(Int_a^b f^2 dy)      sqrt(1/(b-a) Int_a^b f^2 dy)
+// L2Dist(f,g)  = sqrt(Int_a^b (f-g)^2 dy)  sqrt(1/(b-a) Int_a^b (f-g)^2 dy
+// L2IP...(f,g) =      Int_a^b f g dy            1/(b-a) Int_a^b f g dy 
+//                               
+
+Real L2Norm2(const ChebyCoeff& f, bool normalize=true); 
+Real L2Dist2(const ChebyCoeff& f, const ChebyCoeff& g, bool normalize=true); 
+Real L2Norm(const ChebyCoeff& f, bool normalize=true); 
+Real L2Dist(const ChebyCoeff& f, const ChebyCoeff& g, bool normalize=true); 
+Real L2InnerProduct(const ChebyCoeff& f, const ChebyCoeff& g, 
+		    bool normalize=true);
+
+Real chebyNorm2(const ChebyCoeff& f, bool normalize=true); 
+Real chebyDist2(const ChebyCoeff& f, const ChebyCoeff& g, bool normalize=true); 
+Real chebyNorm(const ChebyCoeff& f, bool normalize=true); 
+Real chebyDist(const ChebyCoeff& f, const ChebyCoeff& g, bool normalize=true); 
+Real chebyInnerProduct(const ChebyCoeff& f, const ChebyCoeff& g, 
+		       bool normalize=true);
+
+Real norm2(const ChebyCoeff& f, NormType n, bool normalize=true); 
+Real dist2(const ChebyCoeff& f, NormType n, const ChebyCoeff& g, 
+	   bool normalize=true); 
+Real norm(const ChebyCoeff& f, NormType n, bool normalize=true); 
+Real dist(const ChebyCoeff& f, const ChebyCoeff& g, NormType n, 
+	  bool normalize=true); 
+Real innerProduct(const ChebyCoeff& f, const ChebyCoeff& g, NormType n, 
+		    bool normalize=true);
+
+Real L1Norm(const ChebyCoeff& f, bool normalize=true);
+Real L1Dist(const ChebyCoeff& f, const ChebyCoeff& g, bool normalize=true);
+
+Real LinfNorm(const ChebyCoeff& f); 
+Real LinfDist(const ChebyCoeff& f, const ChebyCoeff& g); 
+
+
 ComplexChebyCoeff operator*(Real c, const ComplexChebyCoeff& g);
 ComplexChebyCoeff operator+(const ComplexChebyCoeff& f, const ComplexChebyCoeff& g);
 ComplexChebyCoeff operator-(const ComplexChebyCoeff& f, const ComplexChebyCoeff& g);
@@ -318,25 +338,6 @@ Real LinfDist(const ComplexChebyCoeff& f, const ComplexChebyCoeff& g);
 
 ComplexChebyCoeff chebyEval(const ComplexChebyCoeff& c, const Vector& x);
 
-class ChebyTransform {
-public:
-  ChebyTransform(int N, int fftw_flags = FFTW_ESTIMATE);
-  ChebyTransform(const ChebyTransform& t);            // unimplemented
-  ChebyTransform& operator=(const ChebyTransform& t); // unimplemented
-  ~ChebyTransform();
-  
-  inline int N() const;
-  inline int length() const;
-
-  friend class ChebyCoeff;
-  friend class ComplexChebyCoeff;
-
-private:
-  int N_; 
-  int flags_;
-  fftw_plan cosfftw_plan_;
-};
-
 inline Real ChebyCoeff::a() const {return a_;}
 inline Real ChebyCoeff::b() const {return b_;}
 inline Real ChebyCoeff::L() const {return b_-a_;}
