@@ -140,8 +140,8 @@ DNS::DNS(FlowField& u, const ChebyCoeff& Ubase, Real nu, Real dt,
 
 DNS::DNS(const DNS& dns) 
   :
-  main_algorithm_(dns.main_algorithm_->clone()),
-  init_algorithm_(dns.init_algorithm_->clone())
+  main_algorithm_(dns.main_algorithm_ ? dns.main_algorithm_->clone() : 0),
+  init_algorithm_(dns.init_algorithm_ ? dns.init_algorithm_->clone() : 0)
 {}
  
 DNSAlgorithm* DNS::newAlgorithm(FlowField& u, const ChebyCoeff& Ubase, 
@@ -182,8 +182,8 @@ DNS::~DNS() {
 DNS& DNS::operator=(const DNS& dns) {
   delete main_algorithm_;
   delete init_algorithm_;
-  main_algorithm_ = dns.main_algorithm_->clone();
-  init_algorithm_ = dns.init_algorithm_->clone();
+  main_algorithm_ = dns.main_algorithm_ ? dns.main_algorithm_->clone() : 0;
+  init_algorithm_ = dns.init_algorithm_ ? dns.init_algorithm_->clone() : 0;
   return *this;
 }  
 
