@@ -397,12 +397,11 @@ FlowField& FlowField::operator=(const FlowField& f) {
 }
 
 FlowField::~FlowField() {
-  fftw_free(scratch_);
-  fftw_free(rdata_);
-  
-  fftw_destroy_plan(y_plan_);
-  fftw_destroy_plan(xz_plan_);
-  fftw_destroy_plan(xz_iplan_);
+  if (scratch_) fftw_free(scratch_);
+  if (rdata_) fftw_free(rdata_);
+  if (y_plan_) fftw_destroy_plan(y_plan_);
+  if (xz_plan_) fftw_destroy_plan(xz_plan_);
+  if (xz_iplan_) fftw_destroy_plan(xz_iplan_);
 }
 
 bool FlowField::isNull() {
@@ -413,8 +412,8 @@ void FlowField::resize(int Nx, int Ny, int Nz, int Nd, Real Lx, Real Lz,
 		       Real a, Real b, int fftw_flags) {
 
   // INEFFICIENT if geometry doesn't change. Should check.
-  fftw_free(scratch_);
-  fftw_free(rdata_);
+  if (scratch_) fftw_free(scratch_);
+  if (rdata_) fftw_free(rdata_);
   if (y_plan_) fftw_destroy_plan(y_plan_);
   if (xz_plan_) fftw_destroy_plan(xz_plan_);
   if (xz_iplan_) fftw_destroy_plan(xz_iplan_);
@@ -452,6 +451,7 @@ void FlowField::resize(int Nx, int Ny, int Nz, int Nd, Real Lx, Real Lz,
   
 void FlowField::fftw_initialize(int flags) {
   flags = flags | FFTW_DESTROY_INPUT;
+  flags = FFTW_MEASURE | FFTW_DESTROY_INPUT;
   
   if (Nx_ !=0 && Nz_ !=0) {
     fftw_complex* fcdata = (fftw_complex*) cdata_;
@@ -556,15 +556,17 @@ void FlowField::interpolate(const FlowField& ff) {
       // So the last mode kx=Mx/2 has an implicit -kx counterpart that is
       // not included in the Fourier representation. For f, this mode is
       // implicitly/automatically included in the Fourier transforms. 
-      // But when copying f onto the larger grid for g, we need to assign
+      // But if g has more x modes than f, we need to assign
       // g(-kxmax) = conj(f(kxmax)) explicitly.
-      int kx = f.kxmax();
-      int fmx = f.mx(kx);
-      int gmx = g.mx(-kx);
-      for (int kz=f.kzmin(); kz<=f.kzmax(); ++kz) {
-	int fmz = f.mz(kz);
-	int gmz = g.mz(kz);
-	g.cmplx(gmx,ny,gmz,i) = conj(f.cmplx(fmx,ny,fmz,i));
+      if (g.Nx() > f.Nx()) {
+	int kx = f.kxmax();
+	int fmx = f.mx(kx);
+	int gmx = g.mx(-kx);
+	for (int kz=f.kzmin(); kz<=f.kzmax(); ++kz) {
+	  int fmz = f.mz(kz);
+	  int gmz = g.mz(kz);
+	  g.cmplx(gmx,ny,gmz,i) = conj(f.cmplx(fmx,ny,fmz,i));
+	}
       }
     }
   f.makeState(fxstate, fystate);
@@ -710,9 +712,9 @@ void FlowField::interpolate(const FlowField& U) {
 ****************************************************************/
 
 void FlowField::optimizeFFTW(int flags) {
-  fftw_destroy_plan(xz_plan_);
-  fftw_destroy_plan(xz_iplan_);
-  fftw_destroy_plan(y_plan_);
+  if (y_plan_) fftw_destroy_plan(y_plan_);
+  if (xz_plan_) fftw_destroy_plan(xz_plan_);
+  if (xz_iplan_) fftw_destroy_plan(xz_iplan_);
 
   flags = flags | FFTW_DESTROY_INPUT;
 
