@@ -75,7 +75,7 @@ public:
 
   FlowField(const FlowField& u);
   FlowField(const string& filebase); // opens filebase.ff
-  FlowField(const string& filebase, const string& chflow_version); // "0.9.15"
+  FlowField(const string& filebase, int major, int minor, int update); 
   ~FlowField();
 
   FlowField& operator = (const FlowField& u); // assign identical copy of U
@@ -118,6 +118,8 @@ public:
   ComplexChebyCoeff profile(int mx, int mz, int i) const;
   BasisFunc profile(int mx, int mz) const; 
 
+  void translate(Real delta_x, Real delta_y);
+
   // Destructive transforms.
   void realfft_xz();
   void irealfft_xz();
@@ -181,10 +183,10 @@ public:
   Vector ygridpts() const;
   Vector zgridpts() const;
   
-  Complex Dx(int mx); // spectral diff operator
-  Complex Dz(int mz); // spectral diff operator
-  Complex Dx(int mx, int n); // spectral diff operator
-  Complex Dz(int mz, int n); // spectral diff operator
+  Complex Dx(int mx) const; // spectral diff operator
+  Complex Dz(int mz) const; // spectral diff operator
+  Complex Dx(int mx, int n) const; // spectral diff operator
+  Complex Dz(int mz, int n) const; // spectral diff operator
 
   FlowField& operator *=(Real x);
   FlowField& operator *=(Complex x);
@@ -272,6 +274,7 @@ private:
   fftw_plan xz_plan_;
   fftw_plan xz_iplan_;
   fftw_plan   y_plan_;
+  //fftw_flags fftw_flags_;
   //fftw_plan  y_iplan_;
   
   inline int flatten(int nx, int ny, int nz, int i) const;
