@@ -124,6 +124,38 @@ PoissonSolver::PoissonSolver(const FlowField& u)
   }
 }
 
+PoissonSolver& PoissonSolver::operator=(const PoissonSolver& ps) {
+
+  if (this == &ps)
+    return *this;
+
+  // Delete old helmholtz solvers
+  for (int mx=0; mx<Mx_; ++mx)
+    delete[] helmholtz_[mx]; // undo new #2
+  delete[] helmholtz_;       // undo new #1
+
+  Mx_ = ps.Mx_;
+  My_ = ps.My_;
+  Mz_ = ps.Mz_;
+  Nd_ = ps.Nd_;
+  Lx_ = ps.Lx_;
+  Lz_ = ps.Lz_;
+  a_ = ps.a_;
+  b_ = ps.b_;
+
+  // Allocate Mx x Mz array of HelmholtzSolvers
+  helmholtz_ = new HelmholtzSolver*[Mx_]; // new #1
+  for (int mx=0; mx<Mx_; ++mx)
+    helmholtz_[mx] = new HelmholtzSolver[Mz_];  // new #2
+  
+  // Assign Helmholtz solvers into array. Each solves p'' - lambda p = f
+  for (int mx=0; mx<Mx_; ++mx) 
+    for (int mz=0; mz<Mz_; ++mz) 
+      helmholtz_[mx][mz] = ps.helmholtz_[mx][mz];
+
+  return *this;
+}
+
 PoissonSolver::~PoissonSolver() {
   for (int mx=0; mx<Mx_; ++mx)
     delete[] helmholtz_[mx]; // undo new #2
@@ -135,6 +167,7 @@ bool PoissonSolver::geomCongruent(const FlowField& u) const {
     (u.Mx() == Mx_) && (u.My() == My_) && (u.Mz()== Mz_) && 
     (u.Lx() == Lx_) && (u.Lz() == Lz_) && (u.a() == a_)  && (u.b() == b_);
 }
+
 bool PoissonSolver::congruent(const FlowField& u) const {
   return 
     (u.Mx() == Mx_) && (u.My() == My_) && (u.Mz()== Mz_) && (u.Nd()== Nd_) &&
@@ -254,7 +287,7 @@ PressureSolver::PressureSolver()
   :
   PoissonSolver(),
   U_(),
-  trans_(0),
+  trans_(1),
   nonl_(),
   tmp_(),
   div_nonl_(),
