@@ -44,9 +44,9 @@ public:
   PoissonSolver(const FlowField& u);
   PoissonSolver(int Nx, int Ny, int Nz, int Nd, Real Lx, Real Lz, Real a, Real b);
 
-  ~PoissonSolver();
   PoissonSolver(const PoissonSolver& ps);
   PoissonSolver& operator=(const PoissonSolver& ps);
+  ~PoissonSolver();
 
   // solve lapl u = f with boundary conditions u=0 or u=bc at y=a and y=b
   void solve(FlowField& u, const FlowField& f) const; // u=0 BC
@@ -91,8 +91,8 @@ public:
   
   ~PressureSolver();
 
-  PressureSolver(const PoissonSolver& ps);
-  PressureSolver& operator=(const PoissonSolver& ps);
+  //PressureSolver(const PoissonSolver& ps);
+  //PressureSolver& operator=(const PoissonSolver& ps);
 
   // solve lapl p = -div nonl(u+U) with BCs dp/dy = d^2 (u+U)/dy^2 at y=a,b
   void solve(FlowField& p, const FlowField& u);
